import browserTargets from './.browserlistrc'
import bpr from '@babel/preset-react'
import bpt from '@babel/preset-typescript'
import bpe from '@babel/preset-env'
import bpsdi from '@babel/plugin-syntax-dynamic-import'
import bprr from 'babel-plugin-react-require'
import bppcp from '@babel/plugin-proposal-class-properties'
import bppoc from '@babel/plugin-proposal-optional-chaining'
import bppnco from '@babel/plugin-proposal-nullish-coalescing-operator'
import sjb from 'styled-jsx/babel'
import sjbt from 'styled-jsx/babel-test'

const jestTargets = { node: 'current' }

const getBabelModuleType = (moduleType) => {
    switch (moduleType) {
        case 'cjs':
        case 'commonjs':
            return 'commonjs'
        case 'systemjs':
        case 'umd':
        case 'amd':
            return moduleType
        case 'es':
        default:
            return false
    }
}
const makeBabelConfig = ({ moduleType, mode }) => {
    const isTest = mode === 'test'

    return {
        presets: [
            bpr,
            bpt,
            [
                bpe,
                {
                    modules: isTest
                        ? 'commonjs'
                        : getBabelModuleType(moduleType),
                    targets: isTest ? jestTargets : browserTargets,
                },
            ],
        ],
        plugins: [
            // Adds syntax support for import()
            bpsdi.default,

            /*
             * These plugins actually transform code
             */

            // Automatically include a React import when JSX is present
            bprr,

            // Adds support for arrow-function class properties
            // class { handleClick = () => { } }
            bppcp,

            // Adds syntax support for optional chaining (?.)
            bppoc,

            // Adds support for default value using ?? operator
            bppnco,
        ],
        env: {
            production: {
                plugins: [
                    [sjb, { optimizeForSpeed: true }],
                ],
            },
            development: {
                plugins: [
                    [sjb, { optimizeForSpeed: true }],
                ],
            },
            test: {
                plugins: [require('styled-jsx/babel-test')],
            },
        },
    }
}

module.exports = makeBabelConfig
